@@ -22,7 +22,7 @@ sub logout : Global {
 sub page : Global {
     my ( $self, $c ) = @_;
     if ( $c->sessionid ) {
-        $c->res->output("you are logged in");
+        $c->res->output("you are logged in, session expires at " . $c->session_expires);
         $c->session->{counter}++;
     }
     else {
